pub struct Key(pub [u8; 16]);Tuple Fields
0: [u8; 16]Implementations
Sourceimpl Key
impl Key
pub fn from_string(string: &str) -> Self
Sourcepub fn do_key_expansion(&self) -> KeySchedule
pub fn do_key_expansion(&self) -> KeySchedule
Generates a series of Round Keys from the Cipher Key. The Key Expansion generates a total of Nb * (Nr + 1) words: the algorithm requires an initial set of Nb words, and each of the Nr rounds requires Nb words of key data. The resulting key schedule consists of a linear array of 4-byte words, denoted [w_i ], with i in the range 0 <= i < Nb * (Nr + 1).